@@ -78,9 +78,7 @@ class Actor:
                             message=f"Actor {self.id} has a lower priority than its waiting target {actor.id}."
                         )
             else:
-                raise TypeError(
-                    f"Actor {self.id} has a wrong type of waiting target."
-                )
+                raise TypeError(f"Actor {self.id} has a wrong type of waiting target.")
 
         # initialize the time
         if callable(at):
@@ -158,18 +156,21 @@ class Actor:
             if self.time == self.till:
                 self.status.append("completed")
             else:
-                self.status.append("onhold")        
+                self.status.append("onhold")
             for actor in self.followers:
                 if actor.onhold:
                     for i, target in enumerate(actor.after):
                         if target is self:
                             actor._waits[i] = False
                     if all(actor._waits) is False:
-                        actor.status.remove('onhold')
-                        actor.status.remove('inactive')
-                        actor.status.append('active')
+                        actor.status.remove("onhold")
+                        actor.status.remove("inactive")
+                        actor.status.append("active")
                         actor._time = self.time
                         self.timeline.schedule(actor)
+            for event in self.timeline.events[:]:
+                if event.actor.id == self.id:
+                    self.timeline.events.remove(event)
 
     def activate(self, force: bool = True):
         if self.active:
